<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Data::SyncthingLauncher</name>
    <message>
        <location filename="../misc/syncthinglauncher.cpp" line="151"/>
        <source>Not built with libsyncthing support.</source>
        <translation>未使用 libsyncthing 支持构建。</translation>
    </message>
</context>
<context>
    <name>QtGui</name>
    <message>
        <location filename="../webview/webviewdialog.cpp" line="249"/>
        <source>Unable to open Syncthing UI via &quot;%1&quot;: %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="89"/>
        <source>The network connection is currently considered metered.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="90"/>
        <source>The network connection is currently not considered metered.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="91"/>
        <source>Unable to determine whether the network connection is metered; assuming an unmetered connection.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::AppearanceOptionPage</name>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="12"/>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="28"/>
        <source>Frame shape</source>
        <translation>框架形状</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="42"/>
        <source>No frame</source>
        <translation>无框架</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="47"/>
        <source>Box</source>
        <translation>盒子</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="52"/>
        <source>Panel</source>
        <translation>面板</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="57"/>
        <source>Styled panel</source>
        <translation>样式面板</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="65"/>
        <source>Frame shadow</source>
        <translation>框架阴影</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="79"/>
        <source>Plain</source>
        <translation>简单</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="84"/>
        <source>Raised</source>
        <translation>提高</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="89"/>
        <source>Sunken</source>
        <translation>凹陷</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="97"/>
        <source>Tab position</source>
        <translation>标签位置</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="111"/>
        <source>Top</source>
        <translation>顶部</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="116"/>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="121"/>
        <source>Left</source>
        <translation>左边</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="126"/>
        <source>Right</source>
        <translation>右边</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="341"/>
        <source>Show tab texts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="355"/>
        <source>Prefer icons from theme over ForkAwesome icons (needs restart to apply)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="364"/>
        <source>Icons</source>
        <translation type="unfinished">图标</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="378"/>
        <source>Popup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="383"/>
        <source>Normal window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="388"/>
        <source>Window without titlebar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="393"/>
        <source>None - open Syncthing directly</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="401"/>
        <source>Window type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="vanished">颜色</translation>
    </message>
    <message>
        <source>Bright custom text colors (use for dark color scheme)</source>
        <translation type="vanished">明亮的自定义文本颜色（用于深色方案）</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="221"/>
        <source>Optional GUI elements</source>
        <translation>可选 GUI 元素</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="334"/>
        <source>Traffic statistics</source>
        <translation>流量数据</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="228"/>
        <source>Positioning</source>
        <translation>定位</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="240"/>
        <source>Use cursor position</source>
        <translation>使用光标位置</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="250"/>
        <source>Otherwise assume tray icon coordinates to be:</source>
        <translation>否则假设托盘图标坐标为：</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="149"/>
        <location filename="../settings/appearanceoptionpage.ui" line="187"/>
        <location filename="../settings/appearanceoptionpage.ui" line="271"/>
        <location filename="../settings/appearanceoptionpage.ui" line="293"/>
        <source> px</source>
        <translation> 像素</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="274"/>
        <source>x: </source>
        <translation>x: </translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="296"/>
        <source>y: </source>
        <translation>y: </translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="134"/>
        <source>Menu size</source>
        <translation>菜单大小</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="171"/>
        <source> x </source>
        <translation> x </translation>
    </message>
</context>
<context>
    <name>QtGui::ApplyWizardPage</name>
    <message>
        <location filename="../settings/applywizardpage.ui" line="6"/>
        <source>General</source>
        <translation type="unfinished">一般</translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="911"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="912"/>
        <source>Apply selected configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="913"/>
        <source>Review the summary of the configuration changes before applying them</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="937"/>
        <source>Summary:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="951"/>
        <source>Keep %1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="951"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="951"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="952"/>
        <source>%1 %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="952"/>
        <source>Enable</source>
        <translation type="unfinished">启用</translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="952"/>
        <source>Disable</source>
        <translation type="unfinished">禁用</translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="962"/>
        <source>Keep connection and launcher configuration as-is</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="965"/>
        <source>Configure Syncthing Tray to use the currently running Syncthing instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="966"/>
        <source>Do &lt;i&gt;not&lt;/i&gt; change how Syncthing is launched</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="970"/>
        <source>Start Syncthing via Syncthing Tray&apos;s launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="972"/>
        <source>executable from PATH as separate process, &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="973"/>
        <source>built-in Syncthing library, &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="978"/>
        <source>Start Syncthing by enabling and starting its systemd unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="980"/>
        <source>Using user unit &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="981"/>
        <source>Using system unit &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="990"/>
        <source>systemd integration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="996"/>
        <source>Preserve existing autostart entry for &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1002"/>
        <source>Override</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1002"/>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1003"/>
        <source>%1 existing autostart entry for &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1005"/>
        <source>autostart of Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1010"/>
        <source>Further information:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1010"/>
        <source>Click on &quot;Show details from setup detection&quot; for further details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1011"/>
        <source>If you want to do amendments, you can head back one or more steps.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1011"/>
        <source>If you abort now, nothing will be changed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::AutostartOptionPage</name>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="12"/>
        <source>Autostart</source>
        <translation>自启动</translation>
    </message>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="27"/>
        <source>Start the tray icon when the desktop environment launches</source>
        <translation>桌面环境启动时启动托盘图标</translation>
    </message>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="75"/>
        <source>Delete existing entry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="817"/>
        <source>This is achieved by adding a *.desktop file under &lt;i&gt;~/.config/autostart&lt;/i&gt; so the setting only affects the current user.</source>
        <translation>这是通过在 &lt;i&gt;~/.config/autostart&lt;/i&gt; 下添加 *.desktop 文件来实现的，因此该设置仅影响当前用户。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="820"/>
        <source>This is achieved by adding a registry key under &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; so the setting only affects the current user. Note that the startup entry is invalidated when moving &lt;i&gt;syncthingtray.exe&lt;/i&gt;.</source>
        <translation>这是通过在 &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; 下添加注册表项来实现的，因此该设置仅影响当前用户。 请注意，移动 &lt;i&gt;syncthingtray.exe&lt;/i&gt; 时启动项无效。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="824"/>
        <source>This is achieved by adding a *.plist file under &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; so the setting only affects the current user.</source>
        <translation>这是通过在 &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; 下添加 *.plist 文件来实现的，因此该设置仅影响当前用户。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="828"/>
        <source>This feature has not been implemented for your platform (yet).</source>
        <translation>此功能尚未为您的平台实现。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1036"/>
        <source>unable to modify startup entry</source>
        <translation>无法修改启动项</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1066"/>
        <source>There is already an autostart entry for &quot;%1&quot;. It will not be overridden when applying changes unless you delete it first.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::AutostartWizardPage</name>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="6"/>
        <source>General</source>
        <translation type="unfinished">一般</translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="19"/>
        <source>Start Syncthing Tray on login (only affects sessions of the current user)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="46"/>
        <source>You previously selected to start Syncthing via the built-in launcher so Syncthing itself will be started automatically on login as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="56"/>
        <source>You previously selected to start Syncthing via systemd so its systemd-unit will be enabled. This means Syncthing itself will start automatically independently of this setting which only affects the tray icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="66"/>
        <source>Since Syncthing is running independently of Syncthing Tray on your system, this does not affect when Syncthing itself is launched.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="76"/>
        <source>The currently running Syncthing instance is started via Syncthing Tray so Syncthing itself will be started automatically on login as well.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/autostartwizardpage.ui" line="86"/>
        <source>This setting is about Syncthing Tray itself. If Syncthing is started via Syncthing Tray&apos;s launcher it will indirectly affect Syncthing as well, though.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="835"/>
        <source>Configure autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="836"/>
        <source>Select whether to start Syncthing Tray automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="890"/>
        <source>Do not modify the existing autostart entry for
&quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::BuiltinWebViewOptionPage</name>
    <message>
        <source>General</source>
        <translation type="obsolete">一般</translation>
    </message>
    <message>
        <source>Syncthing Tray has not been built with vieb view support utilizing either Qt WebKit or Qt WebEngine.
The Web UI will be opened in the default web browser instead.</source>
        <translation type="obsolete">Syncthing Tray 尚未使用 Qt WebKit 或 Qt WebEngine 构建支持网页视图。
网页 UI 将改为在默认网页浏览器中打开。</translation>
    </message>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="12"/>
        <location filename="../settings/settingsdialog.cpp" line="1651"/>
        <source>Built-in web view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="22"/>
        <source>Zoom factor</source>
        <translation type="unfinished">缩放系数</translation>
    </message>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="45"/>
        <source>Hiding</source>
        <translation type="unfinished">隐藏</translation>
    </message>
    <message>
        <location filename="../settings/builtinwebviewoptionpage.ui" line="52"/>
        <source>Keep web view running when currently not shown</source>
        <translation type="unfinished">当前未显示时保持网页视图运行</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1653"/>
        <source>Syncthing Tray has not been built with vieb view support utilizing either Qt WebKit or Qt WebEngine.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::ConnectionOptionPage</name>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="12"/>
        <source>Connection</source>
        <translation>连接</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="30"/>
        <source>Config label</source>
        <translation>配置标签</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="80"/>
        <source>Move currently selected configuration down</source>
        <translation>下移当前选择的配置</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="97"/>
        <source>Move currently selected configuration up</source>
        <translation>上移当前选择的配置</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="114"/>
        <source>Add secondary instance</source>
        <translation>添加辅助实例</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="131"/>
        <source>Remove currently selected secondary instance</source>
        <translation>移除当前选择的辅助实例</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="161"/>
        <source>It is possible to save multiple configurations. This allows switching quickly between multiple Syncthing instances using the connection button in the right corner of the tray menu. The config label is an arbitrary name to identify a configuration and does not have to match the name of the corresponding Syncthing device. The first configuration is the primary/default configuration.</source>
        <translation>可以保存多个配置。 这允许使用托盘菜单右上角的连接按钮在多个 Syncthing 实例之间快速切换。 配置标签是用于标识配置的任意名称，不必与相应 Syncthing 设备的名称匹配。 第一个配置是主要/默认配置。</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="171"/>
        <source>Syncthing URL</source>
        <translation>Syncthing URL</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="185"/>
        <source>Authentication</source>
        <translation>验证</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="202"/>
        <source>User</source>
        <translation>用户</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="219"/>
        <source>Password</source>
        <translation>密码</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="512"/>
        <source>API key</source>
        <translation>API 密钥</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="236"/>
        <source>HTTPS certificate</source>
        <translation>HTTPS 证书</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="178"/>
        <source>&quot;http://host:port/…&quot; or &quot;https://host:port/…&quot;, e.g. &quot;http://127.0.0.1:8384&quot; for local instance with default settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="192"/>
        <source>Supply credentials for HTTP authentication (normally the API key is sufficient)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="267"/>
        <source>Insert values from local Syncthing configuration</source>
        <translation>从本地 Syncthing 配置插入值</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="284"/>
        <source>Select config file manually</source>
        <translation>手动选择配置文件</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="311"/>
        <source>Poll interval</source>
        <translation>拉取间隔</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="335"/>
        <source>Frequency for updating traffic statistics and download speed</source>
        <translation>更新流量数据和下载速度的频率</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="338"/>
        <location filename="../settings/connectionoptionpage.ui" line="381"/>
        <location filename="../settings/connectionoptionpage.ui" line="410"/>
        <location filename="../settings/connectionoptionpage.ui" line="442"/>
        <location filename="../settings/connectionoptionpage.ui" line="539"/>
        <location filename="../settings/connectionoptionpage.ui" line="591"/>
        <source> ms</source>
        <translation> 毫秒</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="351"/>
        <source>Traffic</source>
        <translation>流量</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="358"/>
        <source>Device statistics</source>
        <translation>设备数据</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="378"/>
        <source>Frequency for updating device statistics</source>
        <translation>更新设备数据的频率</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="394"/>
        <source>Errors</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="407"/>
        <source>Frequency to poll for new errors</source>
        <translation>拉取新错误的频率</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="423"/>
        <source>Reconnect</source>
        <translation>重连</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="436"/>
        <source>Time to wait for reconnecting again when the connection to Syncthing has been lost. This setting might be overruled by systemd and launcher settings.</source>
        <translation>当与 Syncthing 的连接丢失时，等待重新连接的时间。 此设置可能会被 systemd 和启动器设置覆盖。</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="439"/>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="461"/>
        <source>Whether to connect automatically on startup. This setting might be overruled by systemd and launcher settings.</source>
        <translation>是否在启动时自动连接。 此设置可能会被 systemd 和启动器设置覆盖。</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="464"/>
        <source>Connect automatically on startup</source>
        <translation>启动时自动连接</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="471"/>
        <source>Overall status</source>
        <translation>总体状态</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="611"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="623"/>
        <source>Select what information should be considered to compute the overall status:</source>
        <translation>选择应考虑哪些信息来计算总体状态：</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="481"/>
        <source>Current status</source>
        <translation>目前状态</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="488"/>
        <source>disconnected</source>
        <translation>已断连</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="501"/>
        <source>Apply connection settings and try to reconnect with the currently selected config</source>
        <translation>应用连接设置并尝试使用当前选择的配置重新连接</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="519"/>
        <source>The API key displayed in Syncthing&apos;s settings dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="526"/>
        <source>The timeout for normal requests to Syncthing&apos;s API. Set to zero to enforce no timeout.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="529"/>
        <source>Transfer timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="536"/>
        <source>no timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="568"/>
        <source>Show advanced configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="578"/>
        <source>The timeout for long-polling requests to Syncthing&apos;s event API. Set to zero to use Syncthing&apos;s default timeout and no timeout being enforced from Syncthing Tray&apos;s side.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="581"/>
        <source>Long polling int.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="588"/>
        <source>Syncthing&apos;s default with no timeout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="604"/>
        <source>Pause all devices while the local network connection is metered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="127"/>
        <source>Auto-detected for local instance</source>
        <translation>本地实例自动检测</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="171"/>
        <source>Select Syncthing config file</source>
        <translation>选择 Syncthing 配置文件</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="179"/>
        <source>Unable to parse the Syncthing config file.</source>
        <translation>无法解析 Syncthing 配置文件。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="276"/>
        <source>Unable to load specified certificate &quot;%1&quot;.</source>
        <translation>无法加载指定的证书 &quot;%1&quot;。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="301"/>
        <source>Instance %1</source>
        <translation>实例 %1</translation>
    </message>
</context>
<context>
    <name>QtGui::DBusStatusNotifier</name>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="25"/>
        <source> - internal error</source>
        <translation> - 内部错误</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="26"/>
        <source> - launcher error</source>
        <translation> - 启动器错误</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="27"/>
        <source>Syncthing notification</source>
        <translation>Syncthing 通知</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="29"/>
        <source> - new device</source>
        <translation> - 新设备</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="30"/>
        <source> - new folder</source>
        <translation> - 新目录</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="33"/>
        <source>Disconnected from Syncthing</source>
        <translation>从 Syncthing 断连</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="34"/>
        <source>Try to reconnect</source>
        <translation>尝试重新连接</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="38"/>
        <location filename="../misc/dbusstatusnotifier.cpp" line="42"/>
        <source>View details</source>
        <translation>查看详情</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="46"/>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="46"/>
        <source>Dismiss</source>
        <translation>解除</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="52"/>
        <source>Open web UI</source>
        <translation>打开网页 UI</translation>
    </message>
</context>
<context>
    <name>QtGui::DetectionWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="527"/>
        <source>Checking current Syncthing setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="528"/>
        <source>Checking Syncthing configuration and whether Syncthing is already running or can be started …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="534"/>
        <source>Check again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="586"/>
        <source>Re-visit setup detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="587"/>
        <source>You might trigger checking the Syncthing setup again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="613"/>
        <source>It looks like Syncthing has not been running on this system before as its configuration cannot be found. Is that correct?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="609"/>
        <source>Yes, continue configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="610"/>
        <source>No, let me select Syncthing&apos;s configuration file manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="619"/>
        <source>Select Syncthing&apos;s configuration file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no</source>
        <translation type="obsolete">否</translation>
    </message>
</context>
<context>
    <name>QtGui::DirectoryErrorsDialog</name>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="28"/>
        <source>Errors for folder %1</source>
        <translation>目录 %1 的错误</translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="46"/>
        <source>Remove non-empty directories</source>
        <translation>删除非空目录</translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/direrrorsdialog.cpp" line="83"/>
        <source>%1 item(s) out-of-sync</source>
        <translation>
            <numerusform>%1 项目未同步</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="113"/>
        <source>Remove non-empty directories for folder &quot;%1&quot;</source>
        <translation>删除文件夹 &quot;%1&quot; 的非空目录</translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="114"/>
        <source>Do you really want to remove the following directories:</source>
        <translation>您真的要删除以下目录吗：</translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="137"/>
        <source>Unable to remove the following dirs:</source>
        <translation>无法删除以下目录：</translation>
    </message>
</context>
<context>
    <name>QtGui::FinalWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="1070"/>
        <source>Waiting for configuration wizard completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1071"/>
        <source>Changes are being applied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1077"/>
        <source>Configuration wizard completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1081"/>
        <source>All changes have been applied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1083"/>
        <source>&lt;p&gt;The configuration has been changed successfully. The way Syncthing Tray connects to and starts Syncthing has not changed, though. You may configure this manually in the settings.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1086"/>
        <source>&lt;p&gt;The configuration has been changed successfully. You can close the wizard and &lt;a href=&quot;openSyncthing&quot;&gt;open Syncthing&lt;/a&gt; to pair remote devices and add folders for sharing. If you need further help, read the &lt;a href=&quot;openDocs&quot;&gt;documentation to get started&lt;/a&gt;.&lt;/p&gt;&lt;p&gt;To initiate the pairing from another device, the device ID of this Syncthing device is displayed below.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1095"/>
        <source>Not all changes could be applied</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="1099"/>
        <source>You may try to head back one or more steps and try again or finish the wizard and configure Syncthing Tray manually.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::GeneralWebViewOptionPage</name>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="12"/>
        <source>General</source>
        <translation type="unfinished">一般</translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="22"/>
        <source>Open Syncthing&apos;s UI via</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="28"/>
        <source>Syncthing Tray&apos;s built-in web view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="35"/>
        <source>Tab in the default web browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="50"/>
        <source>Chromium-based browser in &quot;app mode&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/generalwebviewoptionpage.ui" line="57"/>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1627"/>
        <source>Custom command to launch Syncthing&apos;s UI - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1628"/>
        <source>&lt;p&gt;Enter a custom command to launch Syncthing&apos;s UI. The expression &lt;code&gt;%SYNCTHING_URL%&lt;/code&gt; will be replaced with the Syncthing-URL.&lt;/p&gt;&lt;p&gt;Leave the command empty to use the auto-detection.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::IconsOptionPage</name>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="12"/>
        <source>Icons</source>
        <translation>图标</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="39"/>
        <source>Use Drag &amp; Drop to re-use a selected color at a different position.</source>
        <translation>使用拖放功能在不同位置重复使用选定的颜色。</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="46"/>
        <source>Status icons</source>
        <translation>状态图标</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="54"/>
        <source>Increase the rendering size if you&apos;re using a tray area with extraordinarily big icons.</source>
        <translation>如果您使用带有特大图标的托盘区域，请增加渲染大小。</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="57"/>
        <source>Rendering size</source>
        <translation>渲染大小</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="97"/>
        <source>? px</source>
        <translation>? 像素</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="106"/>
        <source>Stroke width</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="113"/>
        <source>Thick</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="131"/>
        <source>Background color 1</source>
        <translation>背景颜色 1</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="141"/>
        <source>Background color 2</source>
        <translation>背景颜色 2</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="151"/>
        <source>Preview</source>
        <translation>预览</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="164"/>
        <source>Foreground color</source>
        <translation>前景色</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="198"/>
        <source>Restore previous settings</source>
        <translation>还原以前的设置</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="209"/>
        <source>Use preset</source>
        <translation>使用预设</translation>
    </message>
</context>
<context>
    <name>QtGui::IconsOptionPageBase</name>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="639"/>
        <source>UI icons</source>
        <translation>UI 图标</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="641"/>
        <source>These icon settings are used within Syncthing Tray&apos;s UI.</source>
        <translation>这些图标设置在 Syncthing Tray 的 UI 中使用。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="645"/>
        <source>System icons</source>
        <translation>系统图标</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="646"/>
        <source>These icon settings are used for the system tray icon and the notifications.</source>
        <translation>这些图标设置用于系统托盘图标和通知。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="648"/>
        <source>Use same settings as for UI icons</source>
        <translation>使用与 UI 图标相同的设置</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="709"/>
        <source>Colorful background with gradient (default)</source>
        <translation>带渐变的彩色背景（默认）</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="714"/>
        <source>Transparent background and dark foreground (for bright themes)</source>
        <translation>透明背景和深色前景（适用于明亮的主题）</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="719"/>
        <source>Transparent background and bright foreground (for dark themes)</source>
        <translation>透明背景和明亮前景（用于深色主题）</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="735"/>
        <source>%1 px (scaled to %2 px)</source>
        <translation>%1 像素（缩放到 %2 像素）</translation>
    </message>
</context>
<context>
    <name>QtGui::InternalErrorsDialog</name>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="27"/>
        <source>Internal errors</source>
        <translation>内部错误</translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="28"/>
        <source>Request URL:</source>
        <translation>请求 URL：</translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="29"/>
        <source>Response:</source>
        <translation>响应：</translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="55"/>
        <source>Clear errors</source>
        <translation>清除错误</translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/internalerrorsdialog.cpp" line="117"/>
        <source>%1 error(s) occurred</source>
        <translation>
            <numerusform>发生 %1 个错误</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QtGui::LauncherOptionPage</name>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="6"/>
        <source>Syncthing launcher</source>
        <translation>Syncthing 启动器</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="21"/>
        <source>Launch Syncthing when starting the tray icon</source>
        <translation>启动托盘图标时启动 Syncthing</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="43"/>
        <source>Syncthing executable</source>
        <translation>Syncthing 可执行文件</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="53"/>
        <source>Arguments</source>
        <translation>参数</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="63"/>
        <source>Use built-in Syncthing library</source>
        <translation>使用内置 Syncthing 库</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="70"/>
        <source>Set directory for configuration and keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="73"/>
        <source>Config directory</source>
        <translation>配置目录</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="83"/>
        <source>Log level</source>
        <translation>日志等级</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="91"/>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="96"/>
        <source>Verbose</source>
        <translation>Verbose</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="101"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="106"/>
        <source>Warning</source>
        <translation>Warning</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="111"/>
        <source>Fatal</source>
        <translation>Fatal</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="119"/>
        <source>Set database directory (falls back to config directory if empty)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="122"/>
        <source>Data directory</source>
        <translation>数据目录</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="135"/>
        <source>Show start/stop button on tray for local instance</source>
        <translation>在托盘上为本地实例显示开始/停止按钮</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="142"/>
        <source>Consider process status for notifications and reconnect attempts concerning local instance
 • Don&apos;t reconnect when the process is not running
 • Try to reconnect when starting the process
 • Suppress notification about disconnect when Syncthing has been stopped manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="152"/>
        <source>Stop automatically when network connection is metered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Consider process status for reconnect attempts to local instance
 • Don&apos;t reconnect when the process is not running
 • Try to reconnect when starting the process</source>
        <translation type="vanished">考虑重新连接到本地实例的尝试的进程状态
  • 进程未运行时不要重新连接
  • 启动进程时尝试重新连接</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="179"/>
        <source>Syncthing log (interleaved stdout/stderr)</source>
        <translation>同步日志（交错的标准输出/标准错误）</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="192"/>
        <source>Apply and launch now</source>
        <translation>立即应用并启动</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="209"/>
        <location filename="../settings/settingsdialog.cpp" line="1246"/>
        <source>Stop launched instance</source>
        <translation>停止启动的实例</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="228"/>
        <source>No log messages available yet</source>
        <translation>尚无可用的日志消息</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="235"/>
        <source>Ensure latest log is visible</source>
        <translation>确保最新日志可见</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1107"/>
        <source>%1-launcher</source>
        <translation>%1-启动器</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1108"/>
        <source>Launch %1 when starting the tray icon</source>
        <translation>启动托盘图标时启动 %1</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1111"/>
        <source>%1 executable</source>
        <translation>%1 可执行文件</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1112"/>
        <source>%1 log (interleaved stdout/stderr)</source>
        <translation>%1 日志（交错的标准输出/标准错误）</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1129"/>
        <source>Restore default</source>
        <translation>还原至默认</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1135"/>
        <source>Show Syncthing releases/downloads</source>
        <translation>显示 Syncthing 发布/下载</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1281"/>
        <source>%1 exited with exit code %2</source>
        <translation>%1 退出，退出代码为 %2</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1284"/>
        <source>%1 crashed with exit code %2</source>
        <translation>%1 崩溃，退出代码为 %2</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1317"/>
        <source>failed to start (e.g. executable does not exist or not permission error)</source>
        <translation>启动失败（例如可执行文件不存在或没有权限）</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1320"/>
        <source>process crashed</source>
        <translation>进程崩溃</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1323"/>
        <source>timeout error</source>
        <translation>超时错误</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1326"/>
        <source>read error</source>
        <translation>读取错误</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1329"/>
        <source>write error</source>
        <translation>写入错误</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1332"/>
        <source>unknown process error</source>
        <translation>未知进程错误</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1335"/>
        <source>An error occurred when running %1: %2</source>
        <translation>运行 %1 时出错: %2</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1388"/>
        <source>Kill launched instance</source>
        <translation>强制终止启动的实例</translation>
    </message>
</context>
<context>
    <name>QtGui::MainConfigWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="640"/>
        <source>Select what configuration to apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="641"/>
        <source>Something when wrong when checking the Syncthing setup.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="642"/>
        <source>Show details from setup detection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="718"/>
        <source>Systemd</source>
        <translation type="unfinished">Systemd</translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="750"/>
        <source>&lt;b&gt;The Syncthing config could be located under &quot;%1&quot; but it seems invalid/incomplete.&lt;/b&gt; Hence Syncthing is assumed to be not running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="742"/>
        <source>Looks like Syncthing is not running yet. You can launch it via %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="742"/>
        <source> and </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="6"/>
        <source>General</source>
        <translation type="unfinished">一般</translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="23"/>
        <source>Configure Syncthing Tray for currently running Syncthing instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="30"/>
        <source>Start installed Syncthing application via Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="37"/>
        <source>Start Syncthing application that is built into Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="44"/>
        <source>Start Syncthing via systemd user-unit (enables and starts the unit %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="51"/>
        <source>Start Syncthing via systemd system-unit (enables and starts the unit %1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="58"/>
        <source>Keep settings for how to connect to Syncthing and start Syncthing as they are</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="65"/>
        <source>Enable systemd-integration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/mainconfigwizardpage.ui" line="92"/>
        <source>Click next to configure Syncthing Tray according to the selected options. You can also reconduct the checks the available options are based on by heading back. If you cancel the wizard, no configuration changes will be made.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>no</source>
        <translation type="obsolete">否</translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="691"/>
        <source>Looks like Syncthing is already running and Syncthing Tray can be configured accordingly automatically.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="725"/>
        <source>Syncthing Tray&apos;s launcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="744"/>
        <source>Looks like Syncthing is not running yet and needs to be installed before Syncthing Tray can be configured.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::NotificationsOptionPage</name>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="6"/>
        <source>Notifications</source>
        <translation>通知</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="16"/>
        <source>Notify on</source>
        <translation>通知于</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="22"/>
        <source>disconnect</source>
        <translation>断连</translation>
    </message>
    <message>
        <source>internal errors</source>
        <translation type="vanished">内部错误</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="29"/>
        <source>internal errors (if disabled connection errors are only shown within &quot;Internal errors&quot; accessible from the menu!)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="36"/>
        <source>errors/notifications from Syncthing</source>
        <translation>来自 Syncthing 的错误/通知</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="43"/>
        <source>sync of local folder complete</source>
        <translation>本地目录同步完成</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="50"/>
        <source>sync of remote folder complete</source>
        <translation>远程目录同步完成</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="57"/>
        <source>new/unknown device connects</source>
        <translation>新/未知设备连接</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="64"/>
        <source>remote device shares new/unknown folder</source>
        <translation>远程设备共享新/未知目录</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="71"/>
        <source>errors of Syncthing launcher</source>
        <translation>Syncthing 启动器的错误</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="81"/>
        <source>Notification API</source>
        <translation>通知 API</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="87"/>
        <source>D-Bus &amp;notifications (org.freedesktop.Notifications)</source>
        <translation>D-Bus &amp;通知 (org.freedesktop.Notifications)</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="94"/>
        <source>&amp;Method provided by Qt (might be overridden by QPA plugin)</source>
        <translation>&amp;Qt 提供的方法（可能会被 QPA 插件覆盖）</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="104"/>
        <source>Misc</source>
        <translation>杂项</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="110"/>
        <source>Ignore inavailability of Syncthing the specified number of seconds after Syncthing has been started; has only effect if the Syncthing start can be determined which is currently only supported for the local instance started via Systemd or the internal launcher.</source>
        <translation>在 Syncthing 启动后指定的秒数内忽略 Syncthing 的不可用情况； 仅当可以确定 Syncthing 启动时才有效，目前仅支持通过 Systemd 或内部启动器启动的本地实例。</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="120"/>
        <source>don&apos;t ignore</source>
        <translation>不要忽略</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="123"/>
        <source> s</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="484"/>
        <source>Configured to use D-Bus notifications but D-Bus notification daemon seems unavailabe.</source>
        <translation>配置为使用 DBus 通知，但 D-Bus 通知守护程序似乎不可用。</translation>
    </message>
</context>
<context>
    <name>QtGui::OtherDialogs</name>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="30"/>
        <source>Own device ID</source>
        <translation>本设备 ID</translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="40"/>
        <source>device ID is unknown</source>
        <translation>设备 ID 未知</translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="48"/>
        <source>Copy to clipboard</source>
        <translation>复制至剪贴板</translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="85"/>
        <source>Remote/global tree of folder &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::SettingsDialog</name>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1702"/>
        <source>Tray</source>
        <translation>托盘</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1710"/>
        <source>Web view</source>
        <translation>网页视图</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1717"/>
        <source>Startup</source>
        <translation>启动</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1719"/>
        <source>additional tool</source>
        <translation>附加工具</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1719"/>
        <source>Extra launcher</source>
        <translation>额外启动器</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1742"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1748"/>
        <source>Start wizard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::StatusInfo</name>
    <message>
        <source>Initializing ...</source>
        <translation type="vanished">正在初始化 ...</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="46"/>
        <source>Not connected to Syncthing</source>
        <translation>未连接到 Syncthing</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="49"/>
        <source>Trying to reconnect every %1 ms</source>
        <translation>尝试每 %1 毫秒重新连接一次</translation>
    </message>
    <message>
        <source>Reconnecting ...</source>
        <translation type="vanished">重新连接 ...</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="18"/>
        <source>Initializing …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="44"/>
        <source>Connecting to Syncthing …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="55"/>
        <source>Reconnecting …</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="62"/>
        <location filename="../misc/statusinfo.cpp" line="88"/>
        <source>Synchronization is ongoing</source>
        <translation>同步正在进行中</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="63"/>
        <location filename="../misc/statusinfo.cpp" line="67"/>
        <source>At least one folder is out of sync</source>
        <translation>至少有一个目录未同步</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="71"/>
        <source>Notifications available</source>
        <translation>通知可用</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="76"/>
        <source>Syncthing is idling</source>
        <translation>Syncthing 空闲中</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="80"/>
        <source>Syncthing is scanning</source>
        <translation>Syncthing 扫描中</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="84"/>
        <source>At least one device is paused</source>
        <translation>至少有一个设备已暂停</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="92"/>
        <source>At least one remote folder is not in sync</source>
        <translation>至少有一个远程目录未同步</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="96"/>
        <source>Status is unknown</source>
        <translation>状态未知</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="119"/>
        <source>Not connected to other devices</source>
        <translation>未连接到其他设备</translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="143"/>
        <source>Connected to %1 devices</source>
        <translation>
            <numerusform>已连接 %1 个设备</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Connected to %1 and %2 other devices</source>
        <translation type="vanished">
            <numerusform>已连接到 %1 和 %2 个其他设备</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="150"/>
        <source>Connected to %1 and %2</source>
        <translation>
            <numerusform>已连接到 %1 和 %2</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="153"/>
        <source>Connected to %1</source>
        <translation>
            <numerusform>已连接到 %1</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QtGui::SyncthingKiller</name>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="53"/>
        <source>The process %1 (PID: %2) has been requested to terminate but hasn&apos;t reacted yet. Kill the process?

This dialog closes automatically when the process finally terminates.</source>
        <translation>进程 %1 (PID: %2) 已被要求终止，但尚未作出反应。 强制终止进程？

当进程最终终止时，此对话框会自动关闭。</translation>
    </message>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="59"/>
        <source>Keep running</source>
        <translation>保持运行</translation>
    </message>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="60"/>
        <source>Kill process</source>
        <translation>强制终止进程</translation>
    </message>
</context>
<context>
    <name>QtGui::SystemdOptionPage</name>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="6"/>
        <source>Systemd</source>
        <translation>Systemd</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="21"/>
        <source>Show start/stop button on tray for local instance when systemd is available</source>
        <translation>当 systemd 可用时，在托盘上为本地实例显示启动/停止按钮</translation>
    </message>
    <message>
        <source>Consider systemd unit status for reconnect attempts to local instance
 • Don&apos;t reconnect when unit not active/running
 • Try to reconnect when unit becomes active/running</source>
        <translation type="vanished">考虑重新连接到本地实例的 systemd 单元状态
  • 当设备不活动/运行时不要重新连接
  • 当设备变为活动/运行时尝试重新连接</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="28"/>
        <source>Consider systemd unit status for notifications and reconnect attempts concerning local instance
 • Don&apos;t reconnect when unit not active/running
 • Try to reconnect when unit becomes active/running
 • Suppress notification about disconnect when Syncthing has been stopped manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="72"/>
        <source>Syncthing unit</source>
        <translation>Syncthing 单元</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="82"/>
        <source>System unit</source>
        <translation>系统单元</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="95"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="110"/>
        <location filename="../settings/systemdoptionpage.ui" line="165"/>
        <location filename="../settings/systemdoptionpage.ui" line="254"/>
        <location filename="../settings/settingsdialog.cpp" line="1526"/>
        <location filename="../settings/settingsdialog.cpp" line="1535"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="125"/>
        <source>Current status</source>
        <translation>目前状态</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="178"/>
        <source>Start</source>
        <translation>启动</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="195"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="214"/>
        <source>Unit file state</source>
        <translation>单元文件状态</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="267"/>
        <source>Enable</source>
        <translation>启用</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="284"/>
        <source>Disable</source>
        <translation>禁用</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1424"/>
        <source>Reload all unit files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1462"/>
        <source>It is not possible to show the start/stop button for the systemd service and the internal launcher at the same time. The systemd service precedes.</source>
        <translation>无法同时显示 systemd 服务和内部启动器的启动/停止按钮。 systemd 服务优先。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1468"/>
        <source>It is not possible to consider the systemd service and the internal launcher for reconnects at the same time. The systemd service precedes.</source>
        <translation>无法同时考虑 systemd 服务和内部启动器进行重新连接。 systemd 服务优先。</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1499"/>
        <source>specified unit is either inactive or doesn&apos;t exist</source>
        <translation>指定的单位不活动或不存在</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1521"/>
        <source>since </source>
        <translation>自从 </translation>
    </message>
</context>
<context>
    <name>QtGui::TextViewDialog</name>
    <message>
        <location filename="../misc/textviewdialog.cpp" line="61"/>
        <location filename="../misc/textviewdialog.cpp" line="70"/>
        <source>Log</source>
        <translation>日志</translation>
    </message>
</context>
<context>
    <name>QtGui::WebPage</name>
    <message>
        <source>Select path for Syncthing directory ...</source>
        <translation type="vanished">选择 Syncthing 目录的路径 ...</translation>
    </message>
    <message>
        <location filename="../webview/webpage.cpp" line="492"/>
        <source>Select path for Syncthing directory …</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::WebViewDialog</name>
    <message>
        <location filename="../webview/webviewdialog.cpp" line="46"/>
        <source>Syncthing</source>
        <translation>Syncthing</translation>
    </message>
</context>
<context>
    <name>QtGui::WebViewOptionPage</name>
    <message>
        <source>General</source>
        <translation type="vanished">一般</translation>
    </message>
    <message>
        <source>Usage</source>
        <translation type="vanished">用法</translation>
    </message>
    <message>
        <source>Disable web view (open regular web browser instead)</source>
        <translation type="vanished">禁用网页视图（改为打开默认网页浏览器）</translation>
    </message>
    <message>
        <source>Zoom factor</source>
        <translation type="vanished">缩放系数</translation>
    </message>
    <message>
        <source>Hiding</source>
        <translation type="vanished">隐藏</translation>
    </message>
    <message>
        <source>Keep web view running when currently not shown</source>
        <translation type="vanished">当前未显示时保持网页视图运行</translation>
    </message>
    <message>
        <source>Syncthing Tray has not been built with vieb view support utilizing either Qt WebKit or Qt WebEngine.
The Web UI will be opened in the default web browser instead.</source>
        <translation type="vanished">Syncthing Tray 尚未使用 Qt WebKit 或 Qt WebEngine 构建支持网页视图。
网页 UI 将改为在默认网页浏览器中打开。</translation>
    </message>
</context>
<context>
    <name>QtGui::WelcomeWizardPage</name>
    <message>
        <location filename="../settings/wizard.cpp" line="448"/>
        <source>Welcome to Syncthing Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="449"/>
        <source>It looks like you&apos;re launching Syncthing Tray for the first time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="450"/>
        <source>You must configure how to connect to Syncthing and how to launch Syncthing (if that&apos;s wanted) when using Syncthing Tray the first time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="453"/>
        <source>Wizard&apos;s start page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="454"/>
        <source>This wizard will help you configuring Syncthing Tray.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="459"/>
        <source>Start guided setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="461"/>
        <source>Allows to configure Syncthing Tray automatically for the local Syncthing instance and helps you starting Syncthing if wanted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="469"/>
        <source>Configure connection and launcher settings manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="471"/>
        <source>Head back to settings to configure connection and launcher manually</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="474"/>
        <source>Note that the connection settings allow importing URL, credentials and API-key from the local Syncthing configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="490"/>
        <source>Show Syncthing&apos;s documentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="491"/>
        <source>It contains general information about configuring Syncthing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="497"/>
        <source>Show Syncthing Tray&apos;s README</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="498"/>
        <source>It contains documentation about this GUI integration specifically.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtGui::Wizard</name>
    <message>
        <location filename="../settings/wizard.cpp" line="73"/>
        <source>Setup wizard - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="217"/>
        <source>The internal launcher has not been initialized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="229"/>
        <source>The service handler has not been initialized.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="262"/>
        <source>Unable to locate Syncthing config file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="264"/>
        <source>Located Syncthing config file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="266"/>
        <source>Syncthing config file looks ok.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="268"/>
        <source>Syncthing config file looks invalid/incomplete.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="271"/>
        <source>Syncthing configuration:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="279"/>
        <source>Could connect to Syncthing under: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="280"/>
        <source>Syncthing version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="281"/>
        <source>Syncthing device ID: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="282"/>
        <source>Syncthing status: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="284"/>
        <source>Additional Syncthing status info: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="319"/>
        <source>Autostart:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="320"/>
        <source>Currently %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="320"/>
        <source>enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="320"/>
        <source>disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="322"/>
        <source>Points to &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="364"/>
        <source>The Syncthing process exited prematurely. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="377"/>
        <source>The Syncthing service stopped prematurely. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="401"/>
        <source>Ran into timeout while waiting for Syncthing to create config file. Maybe Syncthing created its config file under an unexpected location. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="412"/>
        <source>Checkout Syncthing&apos;s log for details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="416"/>
        <source> It can be accessed within the &lt;a href=&quot;openLauncherSettings&quot;&gt;launcher settings&lt;/a&gt;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="421"/>
        <source> It is normally written to the system journal (and can be accessed via e.g. journalctl).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="289"/>
        <source>API connection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="292"/>
        <source>API connection errors:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="299"/>
        <source>State of user unit file &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="300"/>
        <source>State of system unit file &quot;%1&quot;: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="297"/>
        <source>Systemd:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="287"/>
        <source>Could NOT connect to Syncthing under: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="303"/>
        <source>No available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="309"/>
        <source>Could test-launch Syncthing successfully, exit code: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="310"/>
        <source>Syncthing version returned from test-launch: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="312"/>
        <source>Unable to test-launch Syncthing: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="314"/>
        <source>Built-in Syncthing available: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="314"/>
        <source>yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="314"/>
        <source>no</source>
        <translation type="unfinished">否</translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="315"/>
        <source>Launcher:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings/wizard.cpp" line="330"/>
        <source>Details from setup detection - </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings::Connection</name>
    <message>
        <location filename="../settings/settings.cpp" line="667"/>
        <source>Backup of %1 (created by wizard)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Settings::restore</name>
    <message>
        <location filename="../settings/settings.cpp" line="331"/>
        <source>Unable to load certificate &quot;%1&quot; when restoring settings.</source>
        <translation>还原设置时无法加载证书 &quot;%1&quot;。</translation>
    </message>
</context>
</TS>
